@@ -1,4 +1,5 @@
 import os
+import re
 
 from psycopg2.extensions import parse_dsn
 from tomlkit.toml_file import TOMLFile
@@ -16,8 +17,8 @@ class Config:
             data = {}
         # time to validate some configuration variables
         data.setdefault('database', {'dbname': 'tusker'})
-        data.setdefault('schema', {'filename': 'schema.sql'})
-        data.setdefault('migrations', {'directory': 'migrations'})
+        data.setdefault('schema', {'filename': ['schema.sql']})
+        data.setdefault('migrations', {'filename': ['migrations/*.sql']})
         data.setdefault('migra', {'safe': False, 'privileges': False})
         self.schema = SchemaConfig(data['schema'])
         self.migrations = MigrationsConfig(data['migrations'])
@@ -33,6 +34,14 @@ class Config:
         )
 
 
+def replace_from_env_var(matchobj):
+    env_variable = matchobj.group(1)
+    try:
+        return os.environ[env_variable]
+    except KeyError:
+        raise ConfigError.missing_env(env_variable)
+
+
 class ConfigReader:
 
     def __init__(self, data, path):
@@ -46,16 +55,30 @@ class ConfigReader:
             else:
                 return default
         value = self.data[name]
+
+        if isinstance(value, str):
+            # Replace any environment variables
+            value = re.sub(r"\${([a-zA-Z_][a-zA-Z_0-9]*)}", replace_from_env_var, value)
+
         if not isinstance(value, type):
             raise ConfigError.invalid(name, 'Not of type {}'.format(type))
         return value
 
+    def get_list(self, name, required=False, default=None):
+        value = self.get(name, (str, list), required, default)
+        if isinstance(value, str):
+            value = [value]
+        else:
+            if value and not all(isinstance(x, str) for x in value):
+                raise ConfigError.invalid(name, 'Not a list of strings {}'.format(value))
+        return value
+
 
 class SchemaConfig:
 
     def __init__(self, data):
         data = ConfigReader(data, 'schema')
-        self.filename = data.get('filename', str) or 'schema.sql'
+        self.filename = data.get_list('filename', default=['schema.sql'])
 
     def __str__(self):
         return 'SchemaConfig({!r})'.format(self.__dict__)
@@ -65,15 +88,28 @@ class MigrationsConfig:
 
     def __init__(self, data):
         data = ConfigReader(data, 'migrations')
-        self.directory = data.get('directory', str, False)
-        self.filename = data.get('filename', str, False)
-        if not self.directory and not self.filename:
-            self.directory = 'migrations'
-        elif self.directory and self.filename:
-            raise ConfigError.invalid(
-                'migrations',
-                'directory and filename parameters are mutually exclusive',
+        directory = data.get('directory', str, False)
+        if directory:
+            import warnings
+            warnings.warn(
+                'The "migrations.directory" configuration option is '
+                'deprecated and support for this option will be removed '
+                'in the next version of tusker. Please replace this by '
+                'the "migrations.filename" option which does support '
+                'globbing patterns.',
+                DeprecationWarning,
+                stacklevel=2
             )
+            filename = data.get_list('filename')
+            if filename:
+                raise ConfigError.invalid(
+                    'migrations directory and filename parameters '
+                    'are mutually exclusive',
+                )
+            else:
+                self.filename = ['{}/*.sql'.format(directory)]
+        else:
+            self.filename = data.get_list('filename', default=['migrations/*.sql'])
 
     def __str__(self):
         return 'MigrationsConfig({!r})'.format(self.__dict__)
@@ -118,6 +154,10 @@ class MigraConfig:
 
 class ConfigError(RuntimeError):
 
+    @classmethod
+    def missing_env(cls, env_variable):
+        return cls('Missing environment variable: {}'.format(env_variable))
+
     @classmethod
     def missing(cls, name):
         return cls('Missing configuration: {}'.format(name))
